import { IStyleRule, IStylesheet, IStyleDeclaration, AbstractStylesheetService, IDesignerCanvas, IDesignItem } from "@node-projects/web-component-designer";
import type * as csstree from 'css-tree';
declare global {
    interface Window {
        csstree: {
            fromPlainObject(node: csstree.CssNodePlain): csstree.CssNode;
            toPlainObject(node: csstree.CssNode): csstree.CssNodePlain;
            parse(text: string, options?: csstree.ParseOptions): csstree.CssNode;
            generate(ast: csstree.CssNode, options?: csstree.GenerateOptions): string;
        };
    }
}
interface IRuleWithAST extends IStyleRule {
    ast: csstree.RulePlain;
    declarations: IDeclarationWithAST[];
    stylesheet: IStylesheet;
}
interface IDeclarationWithAST extends IStyleDeclaration {
    ast: csstree.DeclarationPlain;
}
export declare class CssTreeStylesheetService extends AbstractStylesheetService {
    constructor(designerCanvas: IDesignerCanvas);
    internalParse(style: string): Promise<any>;
    private getAppliedRulesInternal;
    getAppliedRules(designItem: IDesignItem): IRuleWithAST[];
    private getDeclarationInternal;
    getDeclarations(designItem: IDesignItem, stlyeName: string): IDeclarationWithAST[];
    updateDeclarationValueWithoutUndo(declaration: IDeclarationWithAST, value: string, important: boolean): void;
    insertDeclarationIntoRule(rule: IRuleWithAST, property: string, value: string, important: boolean): boolean;
    removeDeclarationFromRule(rule: IRuleWithAST, property: string): boolean;
    updateCompleteStylesheet(name: string, newStyle: string): Promise<void>;
    updateCompleteStylesheetWithoutUndo(name: string, newStyle: string, noUndo?: boolean): Promise<void>;
    private updateCompleteStylesheetInternal;
    private rulesFromAST;
    private astHasChildren;
    private buildSelectorString;
    private getSpecificity;
    private findDeclarationInRule;
    private buildAtRuleString;
    private sortDeclarations;
    getRules(selector: string): IStyleRule[];
    addRule(stylesheet: IStylesheet, rule: string): Promise<IStyleRule>;
}
export {};
